<?php

/**
 * WooCP Setup
 * @package WooCP
 * @since 1.0
 */
defined( 'ABSPATH' ) || exit;

/**
 * Main Class WooCP
 */
final class WooCP{

	/**
	 * WooCP Version
	 * @var string
	 */
	public $version = '1.0';

	/**
	 * instance
	 * @var null
	 */
	protected static $_instance = null;

	
	

	/**
	 * WooCP Constructor.
	 */
	public function __construct() {
		$this->includes();
		add_action( 'plugins_loaded', array( $this, 'plugins_loaded' ) );
	}


	public function includes(){

		/**
		 * Class autoloader
		 */
		
		require_once WOOCP_PLUGIN_INC . 'class-woocp-setting.php';

		$folders = array( 'abstract', 'shortcode', 'setting' );
		$this->autoload( $folders );

		// Core Functions
		require_once WOOCP_PLUGIN_INC . 'woocp-core-functions.php';

		// Assets
		require_once WOOCP_PLUGIN_INC . 'class-woocp-assets.php';

		//render css inline
		require_once WOOCP_PLUGIN_INC . '/render-style/render-style.php';

	}

	/**
	 * Load text domain
	 */
	public function plugins_loaded(){

		$prefix = basename( WOOCP_PLUGIN_PATH );
		$locale = get_locale();
		$dir    = untrailingslashit( WOOCP_PLUGIN_PATH ).'/languages';
		$mofile = false;

		$globalFile = WP_LANG_DIR . '/plugins/' . $prefix . '-' . $locale . '.mo';
		$pluginFile = $dir . '/' . $prefix . '-' . $locale . '.mo';

		if ( file_exists( $globalFile ) ) {
			$mofile = $globalFile;
		} else if ( file_exists( $pluginFile ) ) {
			$mofile = $pluginFile;
		}

		if ( $mofile ) {
			// In themes/plugins/mu-plugins directory
			load_textdomain( 'woocp', $mofile );
		}
		
	}
	

	/**
	 * load options object class
	 * @return object class
	 */
	public function options() {
		return Woocp_Setting::instance();
	}


	public function _include( $file ) {
		if ( ! $file ) {
			return;
		}

		if ( is_array( $file ) ) {
			foreach ( $file as $key => $f ) {
				if ( file_exists( WOOCP_PLUGIN_PATH . $f ) ) {
					require_once WOOCP_PLUGIN_PATH . $f;
				}
			}
		} else {
			if ( file_exists( WOOCP_PLUGIN_PATH . $file ) ) {
				require_once WOOCP_PLUGIN_PATH . $file;
			} elseif ( file_exists( $file ) ) {
				require_once $file;
			}
		}
	}

	public function autoload( $folders ){
		foreach ( $folders as $key => $folder ) {
			$real_folder = WOOCP_PLUGIN_INC . $folder;
			foreach ( (array) glob( $real_folder . '/class-woocp-' . $folder . '-*.php' ) as $key => $file ) {
				$this->_include( $file );
			}
		}
	}


	/**
	 * Main WooCP Instance 
	 * Ensures only one instance of WooCP is loaded or can be loaded.
	 * @return WooCP - Main instance.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * Cloning is forbidden.
	 *
	 * @since 1.0
	 */
	public function __clone() {
		wc_doing_it_wrong( __FUNCTION__, esc_html__( 'Cloning is forbidden.', 'woocp' ), '1.0' );
	}



}

