<?php
class Woocp_Settings extends WC_Settings_Page {

    /**
     * Constructor
     */
    public function __construct() {

        $this->id    = 'woocp';

        add_filter( 'woocommerce_settings_tabs_array', array( $this, 'add_settings_tab' ), 50 );
        add_action( 'woocommerce_sections_' . $this->id, array( $this, 'output_sections' ) );
        add_action( 'woocommerce_settings_' . $this->id, array( $this, 'output' ) );
        add_action( 'woocommerce_settings_save_' . $this->id, array( $this, 'save' ) );

    }

    /**
     * Add plugin options tab
     *
     * @return array
     */
    public function add_settings_tab( $settings_tabs ) {
        $settings_tabs[$this->id] = esc_html__( 'Time CountDown', 'woocp' );
        return $settings_tabs;
    }

    /**
     * Get sections
     *
     * @return array
     */
    public function get_sections() {

        $sections = array(
            ''         => esc_html__( 'General', 'woocp' ),
            'shop'         => esc_html__( 'Shop', 'woocp' ),
            'product'         => esc_html__( 'Product', 'woocp' ),
            'shortcode'         => esc_html__( 'Shortcode', 'woocp' ),

        );

        return apply_filters( 'woocommerce_get_sections_' . $this->id, $sections );
    }


    /**
     * Output the settings
     */
    public function output() {
        global $current_section;
        $settings = $this->get_settings( $current_section );
        WC_Admin_Settings::output_fields( $settings );
    }


    /**
     * Save settings
     */
    public function save() {
        global $current_section;
        $settings = $this->get_settings( $current_section );
        WC_Admin_Settings::save_fields( $settings );
    }


    /**
     * Get sections
     *
     * @return array
     */
    public function get_settings( $section = null ) {

        switch( $section ){

            case '' :
                $settings = array(
                    array(
                        'title' => esc_html__( 'General', 'woocp' ),
                        'type'  => 'title',
                        'desc'  => '',
                        'id'    => 'wc_settings_tab_woocp_title_general_woocp',
                    ),

                    array(
                        'name' => esc_html__( 'Countdown Language', 'woocp' ),
                        'type' => 'select',
                        'class' => ' ',
                        'options' => [
                            ''   => 'English',
                            'ar' => 'Arabic',
                            'bg' => 'Bulgarian',
                            'bn' => 'Bengali/Bangla',
                            'bs' => 'Bosnian',
                            'ca' => 'Catalan',
                            'cs' => 'Czech',
                            'cy' => 'Welsh',
                            'da' => 'Danish',
                            'de' => 'German',
                            'el' => 'Greek',
                            'es' => 'Spanish',
                            'et' => 'Estonian',
                            'fa' => 'Farsi/Persian',
                            'fi' => 'Finnish',
                            'fo' => 'Faroese',
                            'fr' => 'French',
                            'gl' => 'Galician',
                            'gu' => 'Gujarati',
                            'he' => 'Hebrew',
                            'hr' => 'Croatian',
                            'hu' => 'Hungarian',
                            'hy' => 'Armenian',
                            'id' => 'Indonesian',
                            'is' => 'Icelandic',
                            'it' => 'Italian',
                            'ja' => 'Japanese',
                            'kn' => 'Kannada',
                            'ko' => 'Korean',
                            'lt' => 'Lithuanian',
                            'lv' => 'Latvian',
                            'mk' => 'Macedonian',
                            'ml' => 'Malayalam',
                            'ms' => 'Malaysian',
                            'my' => 'Burmese',
                            'nb' => 'Norwegian',
                            'nl' => 'Dutch',
                            'pl' => 'Polish',
                            'pt-BR' => 'Portuguese/Brazilian',
                            'ro' => 'Romanian',
                            'ru' => 'Russian',
                            'sk' => 'Slovak',
                            'sl' => 'Slovenian',
                            'sq' => 'Albanian',
                            'sr-SR' => 'Serbian Latin',
                            'sr' => 'Serbian Cyrillic',
                            'sv' => 'Swedish',
                            'th' => 'Thai',
                            'tr' => 'Turkish',
                            'uk' => 'Ukrainian',
                            'ur' => 'Urdu',
                            'uz' => 'Uzbek',
                            'vi' => 'Vietnamese',
                            'zh-CN' => 'Chinese/Simplified',
                            'zh-TW' => 'Chinese/Traditional',
                        ],
                        'default' => '',
                        'id'   => 'wc_settings_tab_woocp_set_language_countdown'
                    ),

                    array(
                        'name' => esc_html__( 'Countdown Format', 'woocp' ),
                        'type' => 'select',
                        'class' => ' ',
                        'options' => [
                            'hms' => esc_html__( 'Hour Minute Seconds', 'woocp' ),
                            'dhms' => esc_html__( 'Day Hour Minute Seconds', 'woocp' ),
                        ],
                        'default' => 'dhms',
                        'id'   => 'wc_settings_tab_woocp_set_format_countdown_display'
                    ),

                    array(
                        'name' => esc_html__( 'Message', 'woocp' ),
                        'type' => 'text',
                        'desc' => esc_html__( 'Use Format: {stock}: number product in stock, {sold}: number product sale, {price}: price of product, {price_saleoff}: price saleoff of product', 'woocp' ),
                        'id'   => 'wc_settings_tab_woocp_message',
                    ),

                    'section_end' => array(
                        'type' => 'sectionend',
                        'id' => 'wc_settings_tab_woocp_end_general'
                    )
                );            

            break;
            case 'shop':
                $settings = array(
                   

                    array(
                        'title' => esc_html__( 'Type Option', 'woocp' ),
                        'type'  => 'title',
                        'id'    => 'woocp_shop_pos_opt_open',
                    ),

                        array(
                            'name' => esc_html__( 'Type', 'woocp' ),
                            'type' => 'select',
                            
                            'options' => [
                               'no' => esc_html__( 'No Display', 'woocp' ),
                               'both' => esc_html__( 'Both Countdown and Quantity Counter', 'woocp' ),
                               'timer_only' => esc_html__( 'Countdown Only', 'woocp' ),
                               'quantity_counter' => esc_html__( 'Quantity Counter Only', 'woocp' ),
                           ],
                           'default' => 'no',
                           'id'   => 'wc_settings_tab_woocp_display_timer_archive'
                        ),

                        array(
                            'name' => esc_html__( 'Position Display Time', 'woocp' ),
                            'type' => 'select',
                            
                            'options' => [
                               'above_title' => esc_html__( 'Above Title', 'woocp' ),
                               'under_title' => esc_html__( 'Under Title', 'woocp' ),
                               'under_price' => esc_html__( 'Under Price', 'woocp' ),
                               'under_add_cart' => esc_html__( 'Under Add To Cart', 'woocp' ),
                           ],
                           'default' => 'under_description',
                           'id'   => 'wc_settings_tab_woocp_position_display_timer_archive'
                        ),

                    array(
                        'type' => 'sectionend',
                        'id'   => 'woocp_shop_pos_opt_closed',
                    ),

                    // Shop Clock Options
                    array(
                        'title' => esc_html__( 'Bar Options', 'woocp' ),
                        'type'  => 'title',
                        'id'    => 'woocp_shop_bar_opt_open',
                    ),

                        array(
                            'name' => esc_html__( 'Message Font Size(px)', 'woocp' ),
                            'type' => 'number',
                            'default' => '18',
                            'id'   => 'wc_settings_tab_woocp_font_szie_message_bar_shop'
                        ),

                         array(
                            'name' => esc_html__( 'Message Color', 'woocp' ),
                            'type' => 'text',
                            'class' => ' color_woocp ',
                            'default' => '#222222',
                            'id'   => 'wc_settings_tab_woocp_color_message_bar_shop'
                        ),

                        array(
                            'name' => esc_html__( 'Background Bar Available', 'woocp' ),
                            'type' => 'text',
                            'class' => ' color_woocp ',
                            'default' => '#f3f3f3',
                            'id'   => 'wc_settings_tab_woocp_background_bar_available_shop'
                        ),

                        array(
                            'name' => esc_html__( 'Background Bar Sale', 'woocp' ),
                            'type' => 'text',
                            'class' => ' color_woocp ',
                            'default' => '#31C864',
                            'id'   => 'wc_settings_tab_woocp_background_bar_sale_shop'
                        ),

                        array(
                            'name' => esc_html__( 'Height Bar (px)', 'woocp' ),
                            'type' => 'number',
                            
                            'default' => '20',
                            'id'   => 'wc_settings_tab_height_bar_shop'
                        ),

                        array(
                            'name' => esc_html__( 'Distance Bar To Countdown (px)', 'woocp' ),
                            'type' => 'number',
                            'default' => '5',
                            'id'   => 'wc_settings_tab_woocp_distance_bar_to_clock_shop'
                        ),

                    array(
                        'type' => 'sectionend',
                        'id'   => 'woocp_shop_bar_opt_close',
                    ),

                    // Shop Countdown Options
                    array(
                        'title' => esc_html__( 'Countdown Options', 'woocp' ),
                        'type'  => 'title',
                        'id'    => 'woocp_shop_countdown_opt_open',
                    ),

                        array(
                            'name' => esc_html__( 'Type', 'woocp' ),
                            'type' => 'select',
                            
                            'options' => [
                                'type1' => esc_html__('Cricle', 'woocp'),
                                'type2' => esc_html__('Square', 'woocp'),
                                'type3' => esc_html__('Full Background', 'woocp'),
                            ],
                            'default' => 'type1',
                            'id'   => 'wc_settings_tab_woocp_type_clock_shop'
                        ),

                        array(
                            'name' => esc_html__( 'Padding Top Bottom Coundown (px)', 'woocp' ),
                            'type' => 'number',
                            'default' => '30',
                            'id'   => 'wc_settings_tab_padding_full_bg_clock_shop'
                        ),

                        array(
                            'name' => esc_html__( 'Background', 'woocp' ),
                            'type' => 'text',
                            'class' => ' color_woocp ',
                            'default' => '#ED6952',
                            'id'   => 'wc_settings_tab_woocp_background_clock_shop'
                        ),

                        array(
                            'name' => esc_html__( 'Width, Height (px)', 'woocp' ),
                            'type' => 'number',
                            
                            'default' => '46',
                            'id'   => 'wc_settings_tab_width_height_clock_shop'
                        ),

                        array(
                            'name' => esc_html__( 'Number Color', 'woocp' ),
                            'type' => 'text',
                            'class' => ' color_woocp ',
                            'default' => '#fff',
                            'id'   => 'wc_settings_tab_woocp_color_number_time_shop'
                        ),

                        array(
                            'name' => esc_html__( 'Number Font-size (px)', 'woocp' ),
                            'type' => 'number',
                            
                            'default' => '16',
                            'id'   => 'wc_settings_tab_woocp_font_szie_number_time_shop'
                        ),

                        array(
                            'name' => esc_html__( 'Label Color', 'woocp' ),
                            'type' => 'text',
                            'class' => ' color_woocp ',
                            'default' => '#fff',
                            'id'   => 'wc_settings_tab_woocp_color_unit_time_shop'
                        ),

                        array(
                            'name' => esc_html__( 'Label Font-size (px)', 'woocp' ),
                            'type' => 'number',
                            
                            'default' => '16',
                            'id'   => 'wc_settings_tab_woocp_font_szie_unit_time_shop'
                        ),

                        array(
                            'name' => esc_html__( 'Distance Clocks In Countdown (px)', 'woocp' ),
                            'type' => 'number',
                            
                            'default' => '6',
                            'id'   => 'wc_settings_tab_woocp_distance_clock_shop'
                        ),

                        array(
                            'name' => esc_html__( 'Distance Countdown To Message (px)', 'woocp' ),
                            'type' => 'number',
                            
                            'default' => '11',
                            'id'   => 'wc_settings_tab_woocp_distance_clock_to_message_shop'
                        ),

                    array(
                        'type' => 'sectionend',
                        'id'   => 'woocp_shop_countdown_opt_closed',
                    ),


                    //message option shop
                    array(
                        'title' => esc_html__( 'Message Options', 'woocp' ),
                        'type'  => 'title',
                        'id'    => 'woocp_shop_message_opt_open',
                    ),

                        array(
                            'name' => esc_html__( 'Show Hide', 'woocp' ),
                            'type' => 'select',
                            'options' => [
                                'yes' => esc_html__( 'Show', 'woocp' ),
                                'no' => esc_html__( 'Hide', 'woocp' ),
                            ],
                            'default' => 'yes',
                            'id'   => 'wc_settings_tab_woocp_show_hide_message_shop'
                        ),
                    
                        array(
                            'name' => esc_html__( 'Message Color', 'woocp' ),
                            'type' => 'text',
                            'class' => ' color_woocp ',
                            'default' => '#333333',
                            'id'   => 'wc_settings_tab_woocp_color_message_shop'
                        ),

                        array(
                            'name' => esc_html__( 'Message Font-Size (px)', 'woocp' ),
                            'type' => 'number',
                            
                            'default' => '18',
                            'id'   => 'wc_settings_tab_woocp_font_size_message_shop'
                        ),

                    array(
                        'type' => 'sectionend',
                        'id'   => 'woocp_shop_message_opt_closed',
                    ),


                    //message variable shop
                    array(
                        'title' => esc_html__( 'Message Variable Options', 'woocp' ),
                        'type'  => 'title',
                        'id'    => 'woocp_shop_message_variable_opt_open',
                    ),
                    
                        array(
                            'name' => esc_html__( 'Message Variable Color', 'woocp' ),
                            'type' => 'text',
                            'class' => ' color_woocp ',
                            'default' => '#333333',
                            'id'   => 'wc_settings_tab_woocp_color_message_variable_shop'
                        ),

                        array(
                            'name' => esc_html__( 'Message Variable Font-Size (px)', 'woocp' ),
                            'type' => 'number',
                            'default' => '18',
                            'id'   => 'wc_settings_tab_woocp_font_size_message_variable_shop'
                        ),

                    array(
                        'type' => 'sectionend',
                        'id'   => 'woocp_shop_message_opt_closed',
                    ),

                );
            break;
            case 'product':
                $settings = array(
                array(
                    'title' => esc_html__( 'Type Options', 'woocp' ),
                    'type'  => 'title',
                    'desc'  => '',
                    'id'    => 'wc_settings_tab_woocp_type_opt_product_woocp',
                ),

                    array(
                        'name' => esc_html__( 'Type', 'woocp' ),
                        'type' => 'select',
                        
                        'options' => [
                           'no' => esc_html__( 'No Display', 'woocp' ),
                           'both' => esc_html__( 'Both Countdown and Quantity Counter', 'woocp' ),
                           'timer_only' => esc_html__( 'Countdown Only', 'woocp' ),
                           'quantity_counter' => esc_html__( 'Quantity Counter Only', 'woocp' ),
                       ],
                       'default' => 'no',
                       'id'   => 'wc_settings_tab_woocp_display_timer_detail'
                   ),

                    array(
                        'name' => esc_html__( 'Position Display Time', 'woocp' ),
                        'type' => 'select',
                        'class' => ' ',
                        'options' => [
                           'above_title' => esc_html__( 'Above Title', 'woocp' ),
                           'under_title' => esc_html__( 'Under Title', 'woocp' ),
                           'under_price' => esc_html__( 'Under Price', 'woocp' ),
                           'under_desc' => esc_html__( 'Under Description', 'woocp' ),
                           'under_add_cart' => esc_html__( 'Under Add To Cart', 'woocp' ),
                       ],
                       'default' => 'under_description',
                       'id'   => 'wc_settings_tab_woocp_position_display_timer_detail'
                   ),


                array(
                    'type' => 'sectionend',
                    'id' => 'wc_settings_tab_woocp_end_type_opt_product'
                ),



                //bar option product
                array(
                    'title' => esc_html__( 'Bar Options', 'woocp' ),
                    'type'  => 'title',
                    'desc'  => '',
                    'id'    => 'wc_settings_tab_woocp_bar_opt_product_woocp',
                ),


                    array(
                        'name' => esc_html__( 'Message Font Size (px)', 'woocp' ),
                        'type' => 'number',
                        'class' => ' ',
                        'default' => '18',
                        'id'   => 'wc_settings_tab_woocp_font_szie_message_bar_product'
                    ),

                    array(
                        'name' => esc_html__( 'Message Color', 'woocp' ),
                        'type' => 'text',
                        'class' => ' color_woocp ',
                        'default' => '#222222',
                        'id'   => 'wc_settings_tab_woocp_color_message_bar_product'
                    ),

                    array(
                        'name' => esc_html__( 'Background Bar Available ', 'woocp' ),
                        'type' => 'text',
                        'class' => ' color_woocp ',
                        'default' => '#f3f3f3',
                        'id'   => 'wc_settings_tab_woocp_background_bar_available_product'
                    ),

                    array(
                        'name' => esc_html__( 'Background Bar Sale', 'woocp' ),
                        'type' => 'text',
                        'class' => ' color_woocp ',
                        'default' => '#31C864',
                        'id'   => 'wc_settings_tab_woocp_background_bar_sale_product'
                    ),


                    array(
                        'name' => esc_html__( 'Height Bar (px)', 'woocp' ),
                        'type' => 'number',
                        
                        'default' => '20',
                        'id'   => 'wc_settings_tab_height_bar_product'
                    ),


                    array(
                        'name' => esc_html__( 'Distance Bar To Countdown (px)', 'woocp' ),
                        'type' => 'number',
                        
                        'default' => '15',
                        'id'   => 'wc_settings_tab_woocp_distance_bar_to_clock_product'
                    ),

                array(
                    'type' => 'sectionend',
                    'id' => 'wc_settings_tab_woocp_end_bar_opt_product'
                ),



                //Countdown option product
                array(
                    'title' => esc_html__( 'Countdown Options', 'woocp' ),
                    'type'  => 'title',
                    'desc'  => '',
                    'id'    => 'wc_settings_tab_woocp_bar_opt_product_woocp',
                ),

                    array(
                        'name' => esc_html__( 'Type', 'woocp' ),
                        'type' => 'select',
                        
                        'options' => [
                            'type1' => esc_html__('Cricle', 'woocp'),
                            'type2' => esc_html__('Square', 'woocp'),
                            'type3' => esc_html__('Full background', 'woocp'),
                        ],
                        'default' => 'type3',
                        'id'   => 'wc_settings_tab_woocp_type_clock_product'
                    ),


                    array(
                        'name' => esc_html__( 'Padding Top Bottom Coundown (px)', 'woocp' ),
                        'type' => 'number',
                        'default' => '30',
                        'id'   => 'wc_settings_tab_padding_full_bg_clock_product'
                    ),


                    array(
                        'name' => esc_html__( 'Background', 'woocp' ),
                        'type' => 'text',
                        'class' => ' color_woocp ',
                        'default' => '#ffffff',
                        'id'   => 'wc_settings_tab_woocp_background_clock_product'
                    ),

                    array(
                        'name' => esc_html__( 'Width, Height (px)', 'woocp' ),
                        'type' => 'number',
                        
                        'default' => '100',
                        'id'   => 'wc_settings_tab_width_height_clock_product'
                    ),

                    array(
                        'name' => esc_html__( 'Number Color', 'woocp' ),
                        'type' => 'text',
                        'class' => ' color_woocp ',
                        'default' => '#1e73be',
                        'id'   => 'wc_settings_tab_woocp_color_number_time_product'
                    ),
                    

                    array(
                        'name' => esc_html__( 'Number Font-size (px)', 'woocp' ),
                        'type' => 'number',
                        
                        'default' => '16',
                        'id'   => 'wc_settings_tab_woocp_font_szie_number_time_product'
                    ),

                    array(
                        'name' => esc_html__( 'Label Color', 'woocp' ),
                        'type' => 'text',
                        'class' => ' color_woocp ',
                        'default' => '#1e73be',
                        'id'   => 'wc_settings_tab_woocp_color_unit_time_product'
                    ),

                    array(
                        'name' => esc_html__( 'Label Font-size (px)', 'woocp' ),
                        'type' => 'number',
                        
                        'default' => '50',
                        'id'   => 'wc_settings_tab_woocp_font_szie_unit_time_product'
                    ),

                    array(
                        'name' => esc_html__( 'Distance Clocks In Countdown (px)', 'woocp' ),
                        'type' => 'number',
                        
                        'default' => '6',
                        'id'   => 'wc_settings_tab_woocp_distance_clock_product'
                    ),

                    array(
                        'name' => esc_html__( 'Distance Countdown To Message (px)', 'woocp' ),
                        'type' => 'number',
                        
                        'default' => '11',
                        'id'   => 'wc_settings_tab_woocp_distance_clock_to_message_product'
                    ),


                array(
                    'type' => 'sectionend',
                    'id' => 'wc_settings_tab_woocp_end_countdown_opt_product'
                ),



                //Message option product
                array(
                    'title' => esc_html__( 'Message Options', 'woocp' ),
                    'type'  => 'title',
                    'desc'  => '',
                    'id'    => 'wc_settings_tab_woocp_message_product_woocp',
                ), 

                    array(
                        'name' => esc_html__( 'Show Hide', 'woocp' ),
                        'type' => 'select',
                        'options' => [
                            'yes' => esc_html__( 'Show', 'woocp' ),
                            'no' => esc_html__( 'Hide', 'woocp' ),
                        ],
                        'default' => 'yes',
                        'id'   => 'wc_settings_tab_woocp_show_hide_message_product'
                    ),

                    array(
                        'name' => esc_html__( 'Message Color', 'woocp' ),
                        'type' => 'text',
                        'class' => ' color_woocp ',
                        'default' => '#333333',
                        'id'   => 'wc_settings_tab_woocp_color_message_product'
                    ),

                    array(
                        'name' => esc_html__( 'Message Font-size (px)', 'woocp' ),
                        'type' => 'number',
                        
                        'default' => '18',
                        'id'   => 'wc_settings_tab_woocp_font_size_message_product'
                    ),

                array(
                    'type' => 'sectionend',
                    'id' => 'wc_settings_tab_woocp_end_message_opt_product'
                ),


                //message variable product
                array(
                    'title' => esc_html__( 'Message Variable Options', 'woocp' ),
                    'type'  => 'title',
                    'id'    => 'woocp_product_message_variable_opt_open',
                ),
                
                    array(
                        'name' => esc_html__( 'Message Variable Color', 'woocp' ),
                        'type' => 'text',
                        'class' => ' color_woocp ',
                        'default' => '#333333',
                        'id'   => 'wc_settings_tab_woocp_color_message_variable_product'
                    ),

                    array(
                        'name' => esc_html__( 'Message Variable Font-Size (px)', 'woocp' ),
                        'type' => 'number',
                        'default' => '18',
                        'id'   => 'wc_settings_tab_woocp_font_size_message_variable_product'
                    ),

                array(
                    'type' => 'sectionend',
                    'id'   => 'woocp_product_message_opt_closed',
                ),

                    
                );


            break;

            case 'shortcode':
                $settings = array(
                array(
                    'title' => esc_html__( 'Type Options', 'woocp' ),
                    'type'  => 'title',
                    'desc'  => '',
                    'id'    => 'wc_settings_tab_woocp_title_shortcode_woocp',
                ),

                    array(
                        'name' => esc_html__( 'Type', 'woocp' ),
                        'type' => 'select',
                        
                        'options' => [
                            'no' => esc_html__( 'No Display', 'woocp' ),
                            'both' => esc_html__( 'Both Countdown and Quantity Counter', 'woocp' ),
                            'timer_only' => esc_html__( 'Countdown Only', 'woocp' ),
                            'quantity_counter' => esc_html__( 'Quantity Counter Only', 'woocp' ),
                        ],
                        'default' => 'no',
                        'id'   => 'wc_settings_tab_woocp_display_timer_shortcode'
                    ),
                    

                    'section_end' => array(
                        'type' => 'sectionend',
                        'id' => 'wc_settings_tab_woocp_end_shortcode'
                    ),


                array(
                    'type' => 'sectionend',
                    'id' => 'wc_settings_tab_woocp_end_type_opt_shortcode'
                ),



                //Title option shortcode
                array(
                    'title' => esc_html__( 'Title Options', 'woocp' ),
                    'type'  => 'title',
                    'desc'  => '',
                    'id'    => 'wc_settings_tab_woocp_title_op_shortcode_woocp',
                ),


                    array(
                        'name' => esc_html__( 'Title Font-size (px)', 'woocp' ),
                        'type' => 'number',
                        'class' => ' ',
                        'default' => '24',
                        'id'   => 'wc_settings_tab_woocp_font_szie_title_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Title Color', 'woocp' ),
                        'type' => 'text',
                        'class' => ' color_woocp ',
                        'default' => '#222222',
                        'id'   => 'wc_settings_tab_woocp_color_title_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Distance Title To Bar (px)', 'woocp' ),
                        'type' => 'number',
                        'default' => '6',
                        'id'   => 'wc_settings_tab_woocp_distance_title_to_bar_shortcode'
                    ),


                array(
                    'type' => 'sectionend',
                    'id' => 'wc_settings_tab_woocp_end_title_shortcode'
                ),


                //Bar option shortcode
                array(
                    'title' => esc_html__( 'Bar Options', 'woocp' ),
                    'type'  => 'title',
                    'desc'  => '',
                    'id'    => 'wc_settings_tab_woocp_bar_op_shortcode_woocp',
                ),


                    array(
                        'name' => esc_html__( 'Message Font-size (px)', 'woocp' ),
                        'type' => 'number',
                        'class' => ' ',
                        'default' => '18',
                        'id'   => 'wc_settings_tab_woocp_font_szie_message_bar_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Message Color', 'woocp' ),
                        'type' => 'text',
                        'class' => ' color_woocp ',
                        'default' => '#222222',
                        'id'   => 'wc_settings_tab_woocp_color_message_bar_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Background Bar Available', 'woocp' ),
                        'type' => 'text',
                        'class' => ' color_woocp ',
                        'default' => '#f3f3f3',
                        'id'   => 'wc_settings_tab_woocp_background_bar_available_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Background Bar Sale', 'woocp' ),
                        'type' => 'text',
                        'class' => ' color_woocp ',
                        'default' => '#31C864',
                        'id'   => 'wc_settings_tab_woocp_background_bar_sale_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Height Bar (px)', 'woocp' ),
                        'type' => 'number',
                        
                        'default' => '20',
                        'id'   => 'wc_settings_tab_height_bar_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Distance Bar To Countdown (px)', 'woocp' ),
                        'type' => 'number',
                        
                        'default' => '15',
                        'id'   => 'wc_settings_tab_woocp_distance_bar_to_clock_shortcode'
                    ),


                array(
                    'type' => 'sectionend',
                    'id' => 'wc_settings_tab_woocp_end_message_opt_shortcode'
                ),


                //Countdown option shortcode
                array(
                    'title' => esc_html__( 'Countdown Options', 'woocp' ),
                    'type'  => 'title',
                    'desc'  => '',
                    'id'    => 'wc_settings_tab_woocp_countdown_opt_shortcode_woocp',
                ),

                    array(
                        'name' => esc_html__( 'Type', 'woocp' ),
                        'type' => 'select',
                        
                        'options' => [
                            'type1' => esc_html__('Cricle', 'woocp'),
                            'type2' => esc_html__('Square', 'woocp'),
                            'type3' => esc_html__('Full Background', 'woocp'),
                        ],
                        'default' => 'type1',
                        'id'   => 'wc_settings_tab_woocp_type_clock_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Padding Top Bottom Coundown (px)', 'woocp' ),
                        'type' => 'number',
                        'default' => '30',
                        'id'   => 'wc_settings_tab_padding_full_bg_clock_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Background', 'woocp' ),
                        'type' => 'text',
                        'class' => ' color_woocp ',
                        'default' => '#ED6952',
                        'id'   => 'wc_settings_tab_woocp_background_clock_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Width, Height (px)', 'woocp' ),
                        'type' => 'number',
                        
                        'default' => '64',
                        'id'   => 'wc_settings_tab_width_height_clock_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Number Color', 'woocp' ),
                        'type' => 'text',
                        'class' => ' color_woocp ',
                        'default' => '#fff',
                        'id'   => 'wc_settings_tab_woocp_color_number_time_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Number Font-size (px)', 'woocp' ),
                        'type' => 'number',
                        
                        'default' => '16',
                        'id'   => 'wc_settings_tab_woocp_font_szie_number_time_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Label Color', 'woocp' ),
                        'type' => 'text',
                        'class' => ' color_woocp ',
                        'default' => '#fff',
                        'id'   => 'wc_settings_tab_woocp_color_unit_time_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Label Font-size (px)', 'woocp' ),
                        'type' => 'number',
                        
                        'default' => '16',
                        'id'   => 'wc_settings_tab_woocp_font_szie_unit_time_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Distance Clocks In Countdown (px)', 'woocp' ),
                        'type' => 'number',
                        
                        'default' => '6',
                        'id'   => 'wc_settings_tab_woocp_distance_clock_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Distance Countdown To Message (px)', 'woocp' ),
                        'type' => 'number',
                        
                        'default' => '11',
                        'id'   => 'wc_settings_tab_woocp_distance_clock_to_message_shortcode'
                    ),

                array(
                    'type' => 'sectionend',
                    'id' => 'wc_settings_tab_woocp_end_countdown_opt_shortcode'
                ),


                //Message option shortcode
                array(
                    'title' => esc_html__( 'Message Options', 'woocp' ),
                    'type'  => 'title',
                    'desc'  => '',
                    'id'    => 'wc_settings_tab_woocp_message_opt_shortcode_woocp',
                ),

                    array(
                        'name' => esc_html__( 'Show Hide', 'woocp' ),
                        'type' => 'select',
                        'options' => [
                            'yes' => esc_html__( 'Show', 'woocp' ),
                            'no' => esc_html__( 'Hide', 'woocp' ),
                        ],
                        'default' => 'yes',
                        'id'   => 'wc_settings_tab_woocp_show_hide_message_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Message Color', 'woocp' ),
                        'type' => 'text',
                        'class' => ' color_woocp ',
                        'default' => '#333333',
                        'id'   => 'wc_settings_tab_woocp_color_message_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Message Font-size (px)', 'woocp' ),
                        'type' => 'number',
                        
                        'default' => '18',
                        'id'   => 'wc_settings_tab_woocp_font_size_message_shortcode'
                    ),


                 array(
                    'type' => 'sectionend',
                    'id' => 'wc_settings_tab_woocp_end_message_opt_shortcode'
                ),

                //message variable shortcode
                array(
                    'title' => esc_html__( 'Message Variable Options', 'woocp' ),
                    'type'  => 'title',
                    'id'    => 'woocp_shortcode_message_variable_opt_open',
                ),
                
                    array(
                        'name' => esc_html__( 'Message Variable Color', 'woocp' ),
                        'type' => 'text',
                        'class' => ' color_woocp ',
                        'default' => '#333333',
                        'id'   => 'wc_settings_tab_woocp_color_message_variable_shortcode'
                    ),

                    array(
                        'name' => esc_html__( 'Message Variable Font-Size (px)', 'woocp' ),
                        'type' => 'number',
                        'default' => '18',
                        'id'   => 'wc_settings_tab_woocp_font_size_message_variable_shortcode'
                    ),

                array(
                    'type' => 'sectionend',
                    'id'   => 'woocp_shortcode_message_opt_closed',
                ),


                );


            break;
        }

        return apply_filters( 'wc_settings_tab_woocp_settings', $settings, $section );
    }
}
return new Woocp_Settings();
