<?php
ob_start();
/**
 * Woocp Core Functions
 *
 * General core functions available on both the front-end and admin.
 *
 * @package Woocp\Functions
 * @version 1.0
 */
defined( 'ABSPATH' ) || exit;


if( !function_exists( 'woocp_locate_template' ) ){
	
	function woocp_locate_template( $template_name, $template_path = '', $default_path = '' ) {
		
		// Set variable to search in templates folder of theme.
		if ( ! $template_path ) :
			$template_path = woocp_template_path();
		endif;

		// Set default plugin templates path.
		if ( ! $default_path ) :
			$default_path = WOOCP_PLUGIN_PATH . 'templates/'; // Path to the template folder
		endif;

		// Search template file in theme folder.
		$template = locate_template( array(
			trailingslashit( $template_path ) . $template_name
			// $template_name
		) );

		// Get plugins template file.
		if ( ! $template ) :
			$template = $default_path . $template_name;
		endif;

		return apply_filters( 'woocp_locate_template', $template, $template_name, $template_path, $default_path );
	}

}


function woocp_get_template( $template_name, $args = array(), $template_path = '', $default_path = '' ) {
	
	if ( is_array( $args ) && isset( $args ) ) :
		extract( $args );
endif;

$template_file = woocp_locate_template( $template_name, $template_path, $default_path );

if ( ! file_exists( $template_file ) ) :
	_doing_it_wrong( __FUNCTION__, sprintf( '<code>%s</code> does not exist.', $template_file ), '1.0.0' );
	return;
endif;

	// Allow 3rd party plugin filter template file
$template_file = apply_filters( 'woocp_get_template', $template_file, $template_name, $args, $template_path, $default_path );

do_action( 'woocp_before_template', $template_name, $template_path, $template_file, $args );

include $template_file;

do_action( 'woocp_after_template', $template_name, $template_path, $template_file, $args );
}

if ( ! function_exists( 'woocp_template_path' ) ) {
	function woocp_template_path() {
		return apply_filters( 'woocp_template_path', 'woocp' );
	}
}



if ( ! function_exists('woocp_get_message_timer_when_replace_variable') ) {
	function woocp_get_message_timer_when_replace_variable ( $product_id = null ) {
		if ( $product_id === null ) return;
		$message_setting = get_option('wc_settings_tab_woocp_message');

		$enable_message_product = ! empty( get_post_meta( $product_id, 'woocp_display_message_product_enable', true ) ) ? get_post_meta( $product_id, 'woocp_display_message_product_enable', true ) : 'global';
		$message_product = ! empty( get_post_meta( $product_id, 'woocp_message_product_content', true ) ) ? get_post_meta( $product_id, 'woocp_message_product_content', true ) : '';

		switch ( $enable_message_product ) {
			case 'global' : {
				$message = $message_setting;
				break;
			}
			case 'yes' : {
				$message = $message_product;
				break;
			}
			case 'no' : {
				$message = '';
				break;
			}
			default : {
				$message = $message_setting;
				break;
			}
		}


		$product = wc_get_product( $product_id );
		$quantity_stock = $sold = $regular_price = $sale_price = null;
		
		if ($product) {
			$quantity_stock = (int)$product->get_stock_quantity();
			$sold = $product->get_total_sales();
			$regular_price = $product->get_regular_price();
			$sale_price = $product->get_sale_price();
		} 
		$message = str_replace( '{stock}', '<span class="woocp_variable">' . $quantity_stock . '</span>', $message );
		$message = str_replace( '{sold}', '<span class="woocp_variable">' . $sold . '</span>', $message ) ;
		$message = str_replace( '{price}', '<span class="woocp_variable">' . wc_price($regular_price) . '</span>', $message );
		$message = str_replace( '{price_saleoff}', '<span class="woocp_variable">' . wc_price($sale_price) . '</span>', $message );

		return $message;
	}
}

add_filter( 'widget_text', 'do_shortcode' );

if ( ! function_exists( 'is_display_bar_quantity_sale' ) ) {
	function is_display_bar_quantity_sale( $product_id = null, $page = 'shop_page' ) {
		if ( $product_id == null ) return false;
		$enable_display_quantity_sale_by_product_id = ! empty( get_post_meta( $product_id, 'woocp_display_quantity_sale_enable', true ) ) ? get_post_meta( $product_id, 'woocp_display_quantity_sale_enable', true ) : 'global' ;

		switch ( $page ) {
			case 'shop_page' : {
				$display_timer = get_option('wc_settings_tab_woocp_display_timer_archive');
				break;
			}
			case 'product_page' : {
				$display_timer = get_option('wc_settings_tab_woocp_display_timer_detail');
				break;
			}
			case 'shortcode_page' : {
				$display_timer = get_option('wc_settings_tab_woocp_display_timer_shortcode');
				break;
			}
		}
		
		$flag = true;
		switch( $display_timer ){
			case "no" : {
				$flag = false;
				break;
			}
			case "timer_only" : {
				$flag = false;
				break;
			}
			default : {
				$flag = true;
				break;
			}
		}

		if ( $enable_display_quantity_sale_by_product_id === 'yes' ) {
			$flag = true;
		} elseif ( $enable_display_quantity_sale_by_product_id === 'no' ) {
			$flag = false;
		}
		return $flag;

	}
}


if ( ! function_exists ( 'woocp_get_data_date_product' ) ) {
	function woocp_get_data_date_product( $product_id = null ) {
		if ( $product_id === null ) return;
		$type_timer = ! empty( get_post_meta( $product_id, 'woocp_type_timer', true ) ) ? get_post_meta( $product_id, 'woocp_type_timer', true ) : 'time_to_upcomming';
		
		$number_day_reset = !empty(get_post_meta($product_id, 'woocp_reset_timer_field', true)) ? floatval(get_post_meta($product_id, 'woocp_reset_timer_field', true)) : 0;

		$sale_price_date_from = ! empty( get_post_meta( $product_id, '_sale_price_dates_from', true ) ) ? get_post_meta( $product_id, '_sale_price_dates_from', true ) : null;
		$sale_price_date_to = ! empty( get_post_meta( $product_id, '_sale_price_dates_to', true ) ) ? get_post_meta( $product_id, '_sale_price_dates_to', true ) : null;

		$current_time = current_time( 'timestamp' );
	
		$data_date = null;
		switch ( $type_timer ) {
			case 'time_to_upcomming' : {
				$data_date = date('Y-m-d H:s:i', $sale_price_date_from);
				break;
			}
			case 'time_to_close_sale' : {
				if ( ( $sale_price_date_from < $current_time ) && ( $current_time < $sale_price_date_to ) ) {
					$data_date = date('Y-m-d H:s:i', $sale_price_date_to);
				}
				break;
			}
			case 'time_reset' : {
				if ( $number_day_reset !== null ) {
					$reset_cookie = false;
					if (isset($_COOKIE['firts_set_time_woocp' . $product_id]) && (($_COOKIE['firts_set_time_woocp' . $product_id] + $number_day_reset * 60 * 60 *24) < $current_time)) {
						$reset_cookie = true;
					}

					if ( isset($_COOKIE['firts_set_time_woocp' . $product_id]) && isset($_COOKIE['number_day_reset_woocp' . $product_id]) && $_COOKIE['number_day_reset_woocp' . $product_id] == $number_day_reset ) {
						if ($reset_cookie) {
							setcookie('firts_set_time_woocp' . $product_id, $current_time, $current_time + 60*60*24*30, '/','');
							setcookie('number_day_reset_woocp' . $product_id, $number_day_reset, $current_time + 60*60*24*30, '/','');
							$cookie_first = $current_time;
						} else {
							$cookie_first = $_COOKIE['firts_set_time_woocp' . $product_id];
						}
					} else {
						setcookie('firts_set_time_woocp' . $product_id, $current_time, $current_time + 60*60*24*30, '/','');
						setcookie('number_day_reset_woocp' . $product_id, $number_day_reset, $current_time + 60*60*24*30, '/','');
						$cookie_first = $current_time;
					}
					$data_date = date('Y-m-d H:i:s', $cookie_first + $number_day_reset * 60 * 60 * 24);
				}
				break;
			}
		}

		return $data_date;
	}
}